==> istio-model-v1beta1-6.5.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl<A extends LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<A>{
  public LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl() {
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl(LoadBalancerSettingsConsistentHashLBUseSourceIp instance) {
    this.withUseSourceIp(instance.getUseSourceIp()); 
  }
  private Boolean useSourceIp;
  public Boolean getUseSourceIp() {
    return this.useSourceIp;
  }
  public A withUseSourceIp(Boolean useSourceIp) {
    this.useSourceIp=useSourceIp; return (A) this;
  }
  public Boolean hasUseSourceIp() {
    return this.useSourceIp != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl that = (LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl) o;
    if (useSourceIp != null ? !useSourceIp.equals(that.useSourceIp) :that.useSourceIp != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(useSourceIp,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (useSourceIp != null) { sb.append("useSourceIp:"); sb.append(useSourceIp); }
    sb.append("}");
    return sb.toString();
  }
  public A withUseSourceIp() {
    return withUseSourceIp(true);
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl<A extends LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<A>{
  public LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl() {
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl(LoadBalancerSettingsConsistentHashLBUseSourceIp instance) {
    if (instance != null) {
      this.withUseSourceIp(instance.getUseSourceIp());
    }
  }
  private Boolean useSourceIp;
  public Boolean getUseSourceIp() {
    return this.useSourceIp;
  }
  public A withUseSourceIp(Boolean useSourceIp) {
    this.useSourceIp=useSourceIp; return (A) this;
  }
  public Boolean hasUseSourceIp() {
    return this.useSourceIp != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl that = (LoadBalancerSettingsConsistentHashLBUseSourceIpFluentImpl) o;
    if (!java.util.Objects.equals(useSourceIp, that.useSourceIp)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(useSourceIp,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (useSourceIp != null) { sb.append("useSourceIp:"); sb.append(useSourceIp); }
    sb.append("}");
    return sb.toString();
  }
  public A withUseSourceIp() {
    return withUseSourceIp(true);
  }
  
}
